weaviate.proto package
======================

.. automodule:: weaviate.proto
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   weaviate.proto.v1
